# Generated by Django 4.1.4 on 2022-12-29 13:12

import aleksis.core.managers
import django.core.validators
from django.contrib.contenttypes.models import ContentType
from django.db import migrations, models
import django.db.models.deletion
import localflavor.generic.models

def _migrate_payment_variants(apps, schema_editor):
    SofortPaymentVariant = apps.get_model("tezor", "SofortPaymentVariant")
    PaypalPaymentVariant = apps.get_model("tezor", "PaypalPaymentVariant")
    SEPADirectDebitPaymentVariant = apps.get_model("tezor", "SEPADirectDebitPaymentVariant")
    PledgePaymentVariant = apps.get_model("tezor", "PledgePaymentVariant")
    Client = apps.get_model("tezor", "Client")

    for client in Client.objects.all():
        if client.sofort_enabled:
            variant = SofortPaymentVariant.objects.create(
                api_id=client.sofort_api_id,
                api_key=client.sofort_api_key,
                project_id=client.sofort_project_id,
                client=client
            )
        if client.paypal_enabled:
            variant = PaypalPaymentVariant.objects.create(
                api_client_id=client.paypal_client_id,
                client_secret=client.paypal_client_secret,
                capture=client.paypal_capture,
                client=client
            )

        if client.sdd_enabled:
            variant = SEPADirectDebitPaymentVariant.objects.create(
                creditor=client.sdd_creditor,
                creditor_identifier=client.sdd_creditor_identifier,
                iban=client.sdd_iban,
                bic=client.sdd_bic,
                client=client
            )

        if client.pledge_enabled:
            variant = PledgePaymentVariant.objects.create(client=client)

    payment_variants = (
        SofortPaymentVariant,
        PaypalPaymentVariant,
        SEPADirectDebitPaymentVariant,
        PledgePaymentVariant,
    )

    for variant in payment_variants:
        ct = ContentType.objects.get_for_model(variant)
        variant.objects.filter(polymorphic_ctype__isnull=True).update(polymorphic_ctype=ct)


class Migration(migrations.Migration):

    dependencies = [
        ("contenttypes", "0002_remove_content_type_name"),
        ("tezor", "0011_drop_sites"),
    ]

    operations = [
        migrations.CreateModel(
            name="PaymentVariant",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
                    ),
                ),
                ("description", models.CharField(max_length=255, verbose_name="Description"
            )),
                ("client", models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='payment_variants', to='tezor.client', verbose_name='Client')),
                ("managed_by_app_label", models.CharField(blank=True, editable=False, max_length=255, verbose_name='App label of app responsible for managing this instance')),
                ("extended_data", models.JSONField(default=dict, editable=False)),
            ],
            options={
                "verbose_name": "Payment variant",
                "verbose_name_plural": "Payment variants",
            },
            managers=[
            ],
        ),
        migrations.AlterModelOptions(
            name="client",
            options={"verbose_name": "Client", "verbose_name_plural": "Clients"},
        ),
        migrations.RemoveConstraint(
            model_name="client",
            name="sofort_enabled_configured",
        ),
        migrations.RemoveConstraint(
            model_name="client",
            name="sdd_enabled_configured",
        ),
        migrations.RemoveConstraint(
            model_name="client",
            name="paypal_enabled_configured",
        ),
        migrations.CreateModel(
            name="PaypalPaymentVariant",
            fields=[
                (
                    "paymentvariant_ptr",
                    models.OneToOneField(
                        auto_created=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        parent_link=True,
                        primary_key=True,
                        serialize=False,
                        to="tezor.paymentvariant",
                    ),
                ),
                (
                    "api_client_id",
                    models.CharField(max_length=255, verbose_name="Client ID"),
                ),
                (
                    "secret",
                    models.CharField(max_length=255, verbose_name="Secret"),
                ),
                (
                    "capture",
                    models.BooleanField(
                        default=False, verbose_name="Use PayPal Authorize & Capture"
                    ),
                ),
                ("endpoint", models.URLField(default="https://api.paypal.com", verbose_name="Endpoint"))
            ],
            options={
                "verbose_name": "PayPal payment variant",
                "verbose_name_plural": "PayPal payment variants",
            },
            bases=("tezor.paymentvariant",),
            managers=[
            ],
        ),
        migrations.CreateModel(
            name="PledgePaymentVariant",
            fields=[
                (
                    "paymentvariant_ptr",
                    models.OneToOneField(
                        auto_created=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        parent_link=True,
                        primary_key=True,
                        serialize=False,
                        to="tezor.paymentvariant",
                    ),
                ),
            ],
            options={
                "verbose_name": "Pledge payment variant",
                "verbose_name_plural": "Pledge payment variants",
            },
            bases=("tezor.paymentvariant",),
            managers=[
            ],
        ),
        migrations.CreateModel(
            name="SEPADirectDebitPaymentVariant",
            fields=[
                (
                    "paymentvariant_ptr",
                    models.OneToOneField(
                        auto_created=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        parent_link=True,
                        primary_key=True,
                        serialize=False,
                        to="tezor.paymentvariant",
                    ),
                ),
                (
                    "creditor",
                    models.CharField(max_length=255, verbose_name="Creditor name"),
                ),
                (
                    "creditor_identifier",
                    models.CharField(
                        max_length=35,
                        validators=[
                            django.core.validators.RegexValidator(
                                "^[A-Z]{2}[0-9]{2}[A-Z0-9]{1,31}$"
                            )
                        ],
                        verbose_name="Creditor identifier",
                    ),
                ),
                (
                    "iban",
                    localflavor.generic.models.IBANField(
                        include_countries=None,
                        max_length=34,
                        use_nordea_extensions=False,
                        verbose_name="IBAN of bank account",
                    ),
                ),
                (
                    "bic",
                    localflavor.generic.models.BICField(
                        max_length=11, verbose_name="BIC/SWIFT code of bank"
                    ),
                ),
            ],
            options={
                "verbose_name": "SEPA Direct Debit payment variant",
                "verbose_name_plural": "SEPA Direct Debit payment variants",
            },
            bases=("tezor.paymentvariant",),
            managers=[
            ],
        ),
        migrations.CreateModel(
            name="SofortPaymentVariant",
            fields=[
                (
                    "paymentvariant_ptr",
                    models.OneToOneField(
                        auto_created=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        parent_link=True,
                        primary_key=True,
                        serialize=False,
                        to="tezor.paymentvariant",
                    ),
                ),
                (
                    "api_id",
                    models.CharField( max_length=255, verbose_name="API ID"),
                ),
                (
                    "api_key",
                    models.CharField( max_length=255, verbose_name="API key"),
                ),
                (
                    "project_id",
                    models.CharField( max_length=255, verbose_name="Project ID"),
                ),
            ],
            options={
                "verbose_name": "Sofort/Klarna payment variant",
                "verbose_name_plural": "Sofort/Klarna payment variants",
            },
            bases=("tezor.paymentvariant",),
            managers=[
            ],
        ),
        migrations.AddField(
            model_name="paymentvariant",
            name="polymorphic_ctype",
            field=models.ForeignKey(
                editable=False,
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="polymorphic_%(app_label)s.%(class)s_set+",
                to="contenttypes.contenttype",
            ),
        ),
        migrations.RunPython(_migrate_payment_variants),
        migrations.RemoveField(
            model_name="client",
            name="paypal_capture",
        ),
        migrations.RemoveField(
            model_name="client",
            name="paypal_client_id",
        ),
        migrations.RemoveField(
            model_name="client",
            name="paypal_enabled",
        ),
        migrations.RemoveField(
            model_name="client",
            name="paypal_secret",
        ),
        migrations.RemoveField(
            model_name="client",
            name="pledge_enabled",
        ),
        migrations.RemoveField(
            model_name="client",
            name="sdd_bic",
        ),
        migrations.RemoveField(
            model_name="client",
            name="sdd_creditor",
        ),
        migrations.RemoveField(
            model_name="client",
            name="sdd_creditor_identifier",
        ),
        migrations.RemoveField(
            model_name="client",
            name="sdd_enabled",
        ),
        migrations.RemoveField(
            model_name="client",
            name="sdd_iban",
        ),
        migrations.RemoveField(
            model_name="client",
            name="sofort_api_id",
        ),
        migrations.RemoveField(
            model_name="client",
            name="sofort_api_key",
        ),
        migrations.RemoveField(
            model_name="client",
            name="sofort_enabled",
        ),
        migrations.RemoveField(
            model_name="client",
            name="sofort_project_id",
        ),
    ]
