from django.db.models.signals import post_save
from django.dispatch import receiver

from aleksis.core.models import Person
from aleksis.core.util.core_helpers import get_site_preferences

from .models.invoice import Invoice


@receiver(post_save, sender=Person)
def update_on_person_change(sender, instance, **kwargs):
    if get_site_preferences()["payments__update_on_person_change"]:
        address = instance.addresses.first()
        street = address.street if address is not None else ""
        housenumber = address.housenumber if address is not None else ""
        postal_code = address.postal_code if address is not None else ""
        place = address.place if address is not None else ""

        Invoice.objects.filter(person=instance, status__in=("waiting", "input", "preauth")).update(
            billing_email=instance.email,
            billing_first_name=instance.first_name,
            billing_last_name=instance.last_name,
            billing_address_1=f"{street} {housenumber}",
            billing_postcode=postal_code,
            billing_city=place,
        )
